@@ -12,7 +12,7 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.4.0'
+VERSION = '0.4.1'
 
 backliftURL = {}
 default_backliftURL = 'https://www.backlift.com/'
@@ -245,11 +245,13 @@ def get_app_meta(api_key, app_id):
     return None
 
 
-def create_app(api_key, name):
+def create_app(api_key, name, template):
     try:
         # import pdb; pdb.set_trace()
-        r = requests.post(backliftURL['create'], data={'appname': name},
-                          auth=HTTPBasicAuth('api', api_key), verify=False)
+        r = requests.post(backliftURL['create'], 
+                          data={'appname': name, 'template': template},
+                          auth=HTTPBasicAuth('api', api_key), 
+                          verify=False)
         check_response(r)
 
         r = json.loads(r.text)
@@ -373,7 +375,7 @@ def create(path, name, template='init'):
     if (os.path.exists(cfg_path)):
         fail(ERR_INIT)
  
-    id = create_app(api_key, name)
+    id = create_app(api_key, name, template)
     if id:
         download_template_files(app_root, template, api_key, {
             'app_id': id
